@@ -40,7 +40,6 @@
 #include "../common/text.h"
 #include "../common/cfgfiles.h"
 #include "../common/xchatc.h"
-#include "../common/plugin.h"
 #include "gtkutil.h"
 #include "maingui.h"
 #include "pixmaps.h"
@@ -50,13 +49,9 @@
 #include "notifygui.h"
 #include "textgui.h"
 #include "fkeys.h"
-#include "plugin-tray.h"
+#include "tray.h"
 #include "urlgrab.h"
 
-#ifdef USE_GTKSPELL
-#include <gtk/gtktextview.h>
-#endif
-
 GdkPixmap *channelwin_pix;
 
 /* === command-line parameter parsing : requires glib 2.6 === */
@@ -68,7 +63,7 @@ static gint arg_show_config = 0;
 static gint arg_show_version = 0;
 static gint arg_minimize = 0;
 
-static const GOptionEntry gopt_entries[] = 
+static const GOptionEntry gopt_entries[] =
 {
  {"no-auto",	'a', 0, G_OPTION_ARG_NONE,	&arg_dont_autoconnect, N_("Don't auto connect to servers"), NULL},
  {"cfgdir",	'd', 0, G_OPTION_ARG_STRING,	&arg_cfgdir, N_("Use a different config directory"), "PATH"},
@@ -122,16 +117,16 @@ fe_args (int argc, char *argv[])
 
 	if (arg_show_autoload)
 	{
-		printf ("%s\n", XCHATLIBDIR"/plugins");
+		printf ("%s\n", CONSPIRE_LIBDIR"/plugins");
 		return 0;
 	}
 
 	if (arg_show_autoloadx)
 	{
-		printf ("%s\n", XCHATLIBDIR"/plugins");
+		printf ("%s\n", CONSPIRE_LIBDIR"/plugins");
 		return 0;
 	}
-	
+
 	if (arg_show_config)
 	{
 		printf ("%s\n", get_xdir_fs ());
@@ -154,11 +149,7 @@ fe_args (int argc, char *argv[])
 const char cursor_color_rc[] =
 	"style \"xc-ib-st\""
 	"{"
-#ifdef USE_GTKSPELL
-		"GtkTextView::cursor-color=\"#%02x%02x%02x\""
-#else
 		"GtkEntry::cursor-color=\"#%02x%02x%02x\""
-#endif
 	"}"
 	"widget \"*.xchat-inputbox\" style : application \"xc-ib-st\"";
 
@@ -237,7 +228,9 @@ fe_idle (gpointer data)
 {
 	session *sess = sess_list->data;
 
-	plugin_add (sess, NULL, NULL, tray_plugin_init, tray_plugin_deinit, NULL, FALSE);
+	/* initialize tray */
+	tray_init();
+	tray_apply_setup();
 
 	if (arg_minimize == 1)
 		gtk_window_iconify (GTK_WINDOW (sess->gui->window));
@@ -551,7 +544,7 @@ fe_set_throttle (server *serv)
 	char tbuf[64];
 	char tip[64];
 
-	per = (float) serv->sendq_len / 1024.0;
+	per = (float) linequeue_size(serv->lq) / ((double) 40);
 	if (per > 1.0)
 		per = 1.0;
 
@@ -560,8 +553,8 @@ fe_set_throttle (server *serv)
 		sess = list->data;
 		if (sess->server == serv)
 		{
-			snprintf (tbuf, sizeof (tbuf) - 1, _("%d bytes"), serv->sendq_len);
-			snprintf (tip, sizeof (tip) - 1, _("Network send queue: %d bytes"), serv->sendq_len);
+			snprintf (tbuf, sizeof (tbuf) - 1, _("%d lines"), linequeue_size(serv->lq));
+			snprintf (tip, sizeof (tip) - 1, _("Network send queue: %d lines"), linequeue_size(serv->lq));
 
 			if (sess->res->queue_tip)
 				free (sess->res->queue_tip);
@@ -652,13 +645,7 @@ fe_gui_info (session *sess, int info_type)
 	case 0:	/* window status */
 		if (!GTK_WIDGET_VISIBLE (GTK_WINDOW (sess->gui->window)))
 			return 2;	/* hidden (iconified or systray) */
-#if GTK_CHECK_VERSION(2,4,0)
 		if (gtk_window_is_active (GTK_WINDOW (sess->gui->window)))
-#else
-#if GTK_CHECK_VERSION(2,2,0)
-		if (GTK_WINDOW (sess->gui->window)->is_active)
-#endif
-#endif
 			return 1;	/* active/focused */
 
 		return 0;		/* normal (no keyboard focus or behind a window) */
@@ -826,31 +813,9 @@ fe_server_event (server *serv, int type, int arg)
 		sess = list->data;
 		if (sess->server == serv && (current_tab == sess || !sess->gui->is_tab))
 		{
-			session_gui *gui = sess->gui;
-
 			switch (type)
 			{
-			case FE_SE_CONNECTING:	/* connecting in progress */
-			case FE_SE_RECONDELAY:	/* reconnect delay begun */
-				/* enable Disconnect item */
-				gtk_widget_set_sensitive (gui->menu_item[MENU_ID_DISCONNECT], 1);
-				break;
-
-			case FE_SE_CONNECT:
-				/* enable Disconnect and Away menu items */
-				gtk_widget_set_sensitive (gui->menu_item[MENU_ID_AWAY], 1);
-				gtk_widget_set_sensitive (gui->menu_item[MENU_ID_DISCONNECT], 1);
-				break;
-
-			case FE_SE_LOGGEDIN:	/* end of MOTD */
-				gtk_widget_set_sensitive (gui->menu_item[MENU_ID_JOIN], 1);
-				break;
-
-			case FE_SE_DISCONNECT:
-				/* disable Disconnect and Away menu items */
-				gtk_widget_set_sensitive (gui->menu_item[MENU_ID_AWAY], 0);
-				gtk_widget_set_sensitive (gui->menu_item[MENU_ID_DISCONNECT], 0);
-				gtk_widget_set_sensitive (gui->menu_item[MENU_ID_JOIN], 0);
+			default:
 				break;
 			}
 		}
@@ -862,7 +827,7 @@ void
 fe_get_file (const char *title, char *initial,
 				 void (*callback) (void *userdata, char *file), void *userdata,
 				 int flags)
-				
+
 {
 	/* OK: Call callback once per file, then once more with file=NULL. */
 	/* CANCEL: Call callback once with file=NULL. */
